pub struct CustomDataDecoder;Expand description
Decoder for custom data types that are identified at runtime by metadata (e.g. type_name).
Only Rust-registered custom types (e.g. RustTestCustomData, MacroYieldCurveData) can be
decoded. Unknown types return an error.
Important: The caller must ensure that any Rust custom data types are registered
via ensure_custom_data_registered::<T>() before use.